import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useDataMap } from './useDataMap';
import { useDataNuclear } from './useDataNuclear';
import { Dropdown } from './Dropdown';
import ReactDropdown from 'react-dropdown';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';

const width = 960;
const height = 500;
const margin = { top: 20, right: 30, bottom: 65, left: 90 };
const dateHistogramSize = 0.25;
const year = d => d.year; // x Value

const attributesPurpose = [
  { value: 'ALL', label: 'All' },
  { value: 'COMBAT', label: 'Combat' },
  { value: 'FMS', label: 'Soviet Test (study)' },
  { value: 'ME', label: 'Military Exercise' },
  { value: 'PNE', label: 'Peaceful Nuclear Explosion' },
  { value: 'SAM', label: 'Soviet Test (accidental/emergency)' },
  { value: 'SSE', label: 'French/US Tests (safety testing)' },
  { value: 'TRANSP', label: 'Transportation-Storage Purposes' },
  { value: 'WE', label: 'British, French, US Evaluate Effects of Detonation' },
  { value: 'WR', label: 'Weapons Development Program' }
];

const attributesType = [
  { value: 'ALL', label: 'All' },
  { value: 'ATMOSPH', label: 'Atmospheric' },
  { value: 'UG', label: 'Underground' },
  { value: 'BALLOON', label: 'Balloon drop' },
  { value: 'AIRDROP', label: 'Airplane deployed' },
  { value: 'ROCKET', label: 'Rocket deployed' },
  { value: 'TOWER', label: 'Deplyed at top of constructed tower' },
  { value: 'WATERSURFACE', label: 'On surface of body of water' },
  { value: 'BARGE', label: 'On barge boat' },
  { value: 'SURFACE', label: 'On surface or in shallow crater' },
  { value: 'UW', label: 'Underwater' },
  { value: 'SHAFT', label: 'Vertical Shaft underground' },
  { value: 'TUNNEL', label: 'Horizontal tunnel' },
  { value: 'GALLERY', label: 'Horizontal gallery' }
];

const App = () => {
  const mapData = useDataMap();
  const nuclearData = useDataNuclear();

  const [hoveredValue, setHoveredValue] = useState(null);
  const [clickedValue, setClickedValue] = useState(null);

  const initialAttributePurpose = 'ALL';
  const [attributePurpose, setAttributePurpose] = useState(
    initialAttributePurpose
  );
  const purpose = d => d[attributePurpose];
  console.log('Chosen: ', attributePurpose);

  const initialAttributeType = 'ALL';
  const [attributeType, setAttributeType] = useState(initialAttributeType);
  const type = d => d[attributeType];
  console.log('Chosen: ', attributeType);

  const [brushExtent, setBrushExtent] = useState();
  
  if (!mapData || !nuclearData) {
    return <pre>Loading...</pre>;
  }

  return (
    <>
      <div className="menus-container">
        <span className="dropdown-label">Purpose of Deployments:</span>
        <ReactDropdown
          options={attributesPurpose}
          value={attributePurpose}
          onChange={({ value }) => setAttributePurpose(value)}
        />
        <span className="dropdown-label">Type of Deployments:</span>
        <ReactDropdown
          options={attributesType}
          value={attributeType}
          onChange={({ value }) => setAttributeType(value)}
        />
      </div>
      <svg width={width} height={height}>
        <BubbleMap
          nuclearData={nuclearData}
          mapData={mapData}
          setClickedValue={setClickedValue}
          attributePurpose={attributePurpose}
          attributeType={attributeType}
          setHoveredValue={setHoveredValue}
          hoveredValue={hoveredValue}
          clickedValue={clickedValue}
          width={width}
          height={height}
          brushExtent={brushExtent}
          year={year}
        />
        <g transform={`translate(0, ${height - dateHistogramSize * height})`}>
          <DateHistogram
            nuclearData={nuclearData}
            width={width}
            height={dateHistogramSize * height}
            setBrushExtent={setBrushExtent}
            year={year}
          />
        </g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
